@@ -379,18 +379,6 @@ class TerraformCommonWrapper:
                             logger.debug("Removed .terraform/terraform.tfstate")
 
                         logger.info("Switching to using existing workspace")
-                        #os.system(f"terraform workspace select {workspace} || terraform workspace new {workspace}")
-                        #os.system("terraform init")
-                        # try:
-                        #     subprocess.check_output(
-                        #         ["terraform", "workspace", "select", workspace]
-                        #     )
-                        #     logger.info(f"Workspace {workspace} already exists")
-                        # except subprocess.CalledProcessError as e:
-                        #     subprocess.check_output(
-                        #         ["terraform", "workspace", "new", workspace]
-                        #     )
-                        #     logger.info(f"Created workspace {workspace}")
                         if self.aws_profile is not None:
                             cmd = (
                                 'terraform init -backend-config="bucket={}" '
@@ -417,17 +405,23 @@ class TerraformCommonWrapper:
                             )
                         logger.debug("init command: {}".format(cmd))
                         ret_code = run_command.run_cmd(cmd)
-                        os.system(f"terraform workspace select {workspace} || terraform workspace new {workspace}")
-                        # try:
-                        #     subprocess.check_output(
-                        #         ["terraform", "workspace", "select", workspace]
-                        #     )
-                        #     logger.info(f"Workspace {workspace} already exists")
-                        # except subprocess.CalledProcessError as e:
-                        #     subprocess.check_output(
-                        #         ["terraform", "workspace", "new", workspace]
-                        #     )
-                        #     logger.info(f"Created workspace {workspace}")
+                        # os.system(f"terraform workspace select {workspace} || terraform workspace new {workspace}")
+                        try:
+                            cmd_out = subprocess.check_output(
+                                ["terraform", "workspace", "select", workspace],
+                                stderr=subprocess.STDOUT,
+                                shell=True,
+                            )
+                            logger.info(
+                                f"Workspace {workspace} already exists {cmd_out}"
+                            )
+                        except subprocess.CalledProcessError as e:
+                            cmd_out = subprocess.check_output(
+                                ["terraform", "workspace", "new", workspace],
+                                stderr=subprocess.STDOUT,
+                                shell=True,
+                            )
+                            logger.info(f"Created workspace {workspace} {cmd_out}")
                         if ret_code == 0:
                             return True
                         else:
